@@ -1,10 +1,11 @@
 import paho.mqtt.client as mqtt
-from hive.core import HivePubSub, HiveWorker
+from hive.core import HiveBytePubSub, json_encoder, json_decoder
 
 
-class HiveMqtt(HivePubSub):
+class HiveMqtt(HiveBytePubSub):
 
     def __init__(self,
+                 # Connection options
                  host="localhost",
                  port=1883,
                  keepalive=60,
@@ -13,12 +14,18 @@ class HiveMqtt(HivePubSub):
                  clean_start=mqtt.MQTT_CLEAN_START_FIRST_ONLY,
                  properties=None,
 
+                 # client options
                  client_id="",
                  clean_session=None,
                  userdata=None,
                  protocol=mqtt.MQTTv311,
-                 transport="tcp"
+                 transport="tcp",
+
+                 # encoder options
+                 encoder=json_encoder,
+                 decoder=json_decoder
                  ):
+        super().__init__(encoder, decoder)
         self.client = mqtt.Client(client_id, clean_session, userdata, protocol, transport)
         self.client.connect(host, port, keepalive, bind_address, bind_port, clean_start, properties)
         self.client.on_message = self.on_message()  # we use this to close over self so we can access the subscription list
@@ -41,4 +48,4 @@ class HiveMqtt(HivePubSub):
         self.client.publish(topic, message)
 
     def spin(self):
-        self.client.loop_forever()
\ No newline at end of file
+        self.client.loop_forever()
